Documentation
¶
Index ¶
- Constants
- func FindOrphanedCPUs(domains []PCIeDomain, allCPUs cpuset.CPUSet) cpuset.CPUSet
- func IsPCIeRootName(name string) bool
- func MapCPUsToPCIeDomain(domains []PCIeDomain, allCPUs cpuset.CPUSet) map[int][]*PCIeDomain
- func SetCompatibilityAttributes(attrs map[resourceapi.QualifiedName]resourceapi.DeviceAttribute, numaID int64)
- type PCIeDomain
- type SysFS
Constants ¶
const (
SysfsRoot = "/sys"
)
Variables ¶
This section is empty.
Functions ¶
func FindOrphanedCPUs ¶ added in v0.2.0
func FindOrphanedCPUs(domains []PCIeDomain, allCPUs cpuset.CPUSet) cpuset.CPUSet
func IsPCIeRootName ¶ added in v0.2.0
IsPCIeRootName matches the constructions of the pcie roots in the linux kernel. The kernel format string is "pci%04x:%02x" (linux 7.0.9: drivers/pci/probe.c:1028).
func MapCPUsToPCIeDomain ¶ added in v0.2.0
func MapCPUsToPCIeDomain(domains []PCIeDomain, allCPUs cpuset.CPUSet) map[int][]*PCIeDomain
MapCPUsToPCIeDomain returns a map cpuid -> pciedomains
func SetCompatibilityAttributes ¶
func SetCompatibilityAttributes(attrs map[resourceapi.QualifiedName]resourceapi.DeviceAttribute, numaID int64)
SetCompatibilityAttributes add attributes to enable compatibility (e.g. alignment) with other DRA resource drivers leveraging attributes which are not kubernetes standard. This is the "staging area" which enables attribute sharing until (or before) they become standard.
Types ¶
type PCIeDomain ¶ added in v0.2.0
func PCIeDomainsFromFS ¶ added in v0.2.0
func PCIeDomainsFromFS(logger logr.Logger, sysfs SysFS) ([]PCIeDomain, error)
func (PCIeDomain) String ¶ added in v0.2.0
func (pcd PCIeDomain) String() string
Click to show internal directories.
Click to hide internal directories.